@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::Author::Plicease::MakeMaker 2.26 {
+package Dist::Zilla::Plugin::Author::Plicease::MakeMaker 2.27 {
 
   use 5.014;
   use Moose;
@@ -31,10 +31,10 @@ package Dist::Zilla::Plugin::Author::Plicease::MakeMaker 2.26 {
     
     $self->$orig(@args);
     
-    my $file = first { $_->name eq 'Makefile.PL' } @{ $self->zilla->files };
-    my $mod  = first { $_->name eq 'inc/mymm.pl' } @{ $self->zilla->files };
+    my $file  = first { $_->name eq 'Makefile.PL' }  @{ $self->zilla->files };
+    my $mod   = first { $_->name eq 'inc/mymm.pl' }  @{ $self->zilla->files };
+    my $build = first { $_->name eq 'inc/mymm-build.pl' } @{ $self->zilla->files };
 
-    $DB::single = 1;
     my @content = do {
       my $in  = $file->content;
       my $out = '';
@@ -132,6 +132,16 @@ package Dist::Zilla::Plugin::Author::Plicease::MakeMaker 2.26 {
       }
     }
 
+
+    if($build)
+    {
+      push @content, "sub MY::postamble {";
+      push @content, "  \"pure_all :: mymm_build\\n\" .";
+      push @content, "  \"mymm_build :\\n\" .";
+      push @content, "  \"\\t\\\$(FULLPERL) inc/mymm-build.pl\\n\"";
+      push @content, "}";
+    }
+
     $file->content(join "\n", @content);
 
     return;
@@ -183,7 +193,7 @@ Dist::Zilla::Plugin::Author::Plicease::MakeMaker - munge the AUTHOR section
 
 =head1 VERSION
 
-version 2.26
+version 2.27
 
 =head1 SYNOPSIS
 
